==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/module/imrahil.pl <==
#============================================================================================================
#
#	OǗW[
#	imrahil.pl
#	-------------------------------------------------------------------------------------
#	2005.04.02 start
#
#============================================================================================================
package	IMRAHIL;
use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#	Modẽrbgɂ
#	--------------------------------------
#	0:ǎp
#	1:I[vƓɓeǂݍ
#	2:őTCY𒴂Oۑ
#	3`:gp
#------------------------------------------------------------------------------------------------------------

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($File, $Limit, $Mode) = @_;
	my ($obj, @LOGS);
	local *HANDLE;
	
	$obj = {
		'LOGS'		=> \@LOGS,
		'PATH'		=> $File,
		'SIZE'		=> 0,
		'HANDLE'	=> *HANDLE,
		'LIMIT'		=> $Limit,
		'STAT'		=> 0,
		'MODE'		=> $Mode
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	fXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DESTROY
{
	my $this = shift;
	
	# t@CI[vԂ̏ꍇ̓N[Y
	if ($this->{'STAT'}) {
		my $handle = $this->{'HANDLE'};
		if ($handle) {
#			eval
			{
				close $handle;
			};
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	OI[v
#	-------------------------------------------------------------------------------------
#	@param	$File	Ot@CpX(gq)
#	@param	$Limit	OőTCY
#	@param	$Mode	[h
#	@return	:0,s:-1
#
#------------------------------------------------------------------------------------------------------------
sub Open
{
	my $this = shift;
	my ($File, $Limit, $Mode) = @_;
	my $ret = -1;
	
	if (defined $File && defined $Limit && defined $Mode) {
		$this->{'PATH'} = $File;
		$this->{'LIMIT'} = $Limit;
		$this->{'MODE'} = $Mode;
	}
	else {
		$File = $this->{'PATH'};
		$Limit = int $this->{'LIMIT'};
		$Mode = int $this->{'MODE'};
	}
	
	if (defined  $this->{'HANDLE'}) {
		local *HANDLE;
		$this->{'HANDLE'} = *HANDLE;
	}
	$File .= '.cgi';
	
#	eval
	{
		if ($this->{'STAT'} == 0) {
			my $handle = $this->{'HANDLE'};
			open $handle, "+>> $File";
			flock $handle, 2 if ($Mode & 1);
			binmode $handle;
			
			$this->{'STAT'} = 1;
			$ret = 0;
			if ($Mode & 2) {
				$ret = $this->Read();
			}
		}
	};
	return $ret;
}

#------------------------------------------------------------------------------------------------------------
#
#	ON[Y
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Close
{
	my $this = shift;
	
	if ($this->{'STAT'} == 1) {
#		eval
		{
			my $handle = $this->{'HANDLE'};
			close $handle;
			$this->{'STAT'} = 0;
		};
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ǂݍ
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	:0,s:-1
#
#------------------------------------------------------------------------------------------------------------
sub Read
{
	my $this = shift;
	my $ret = -1;
	
	if ($this->{'STAT'} == 1) {
#		eval
		{
			my $handle = $this->{'HANDLE'};
			my $count = 0;
			undef @{$this->{'LOGS'}};
			seek $handle, 0, 0;
			while (<$handle>) {
				chomp $_;
				push @{$this->{'LOGS'}}, $_;
				$count++;
			}
			$this->{'SIZE'} = $count;
			$ret = 0;
		};
	}
	return $ret;
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Write
{
	my $this = shift;
	
	# t@CI[vԂȂ珑݂s
	if ($this->{'STAT'}) {
		if (! ($this->{'MODE'} & 1)) {
			my $handle = $this->{'HANDLE'};
#			eval
			{
				truncate $handle, 0;
				seek $handle, 0, 0;
				for (my $i = 0 ; $i < $this->{'SIZE'} ; $i++) {
					print $handle $this->{'LOGS'}->[$i] . "\n";
				}
				close $handle;
			};
			$this->{'STAT'} = 0;
		}
		else {
			$this->Close();
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	f[^擾
#	-------------------------------------------------------------------------------------
#	@param	$line	擾f[^s
#	@return	擾f[^
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($line) = @_;
	
	if ($line < $this->{'SIZE'}) {
		return $this->{'LOGS'}->[$line];
	}
	return undef;
}

#------------------------------------------------------------------------------------------------------------
#
#	f[^ǉ
#	-------------------------------------------------------------------------------------
#	@param	$pData	ǉf[^
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Put
{
	my $this = shift;
	my (@datas) = @_;
	my ($logData, $tm);
	
	if ($this->{'SIZE'} + 1 > $this->{'LIMIT'}) {
		my $old = shift @{$this->{'LOGS'}};
		if ($this->{'MODE'} & 4) {
			my $logName = $this->{'PATH'} . '_old.cgi';
#			eval
			{
				open OLDLOG, ">> $logName";
				flock OLDLOG, 2;
				binmode OLDLOG;
				print OLDLOG "$old\n";
				close OLDLOG;
			};
		}
		$this->{'SIZE'}--;
	}
	$tm = time;
	$logData = join('<>', $tm, @datas);
	
	push @{$this->{'LOGS'}}, $logData;
	$this->{'SIZE'}++;
}

#------------------------------------------------------------------------------------------------------------
#
#	TCY擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	TCY
#
#------------------------------------------------------------------------------------------------------------
sub Size
{
	my $this = shift;
	return $this->{'SIZE'};
}

#------------------------------------------------------------------------------------------------------------
#
#	Oޔ
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub MoveToOld
{
	my $this = shift;
	my ($i);
	
#	eval
	{
		open OLDLOG, ">> " . $this->{'PATH'} . '_old.cgi';
		flock OLDLOG, 2;
		binmode OLDLOG;
		for($i = 0 ; $i < $this->{'SIZE'} ; $i++) {
			print OLDLOG $this->{'LOGS'}->[$i] . "\n";
		}
		close OLDLOG;
	};
}

#------------------------------------------------------------------------------------------------------------
#
#	ONA
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	undef @{$this->{'LOGS'}};
	$this->{'SIZE'} = 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	$index		vf̃CfNX
#	@param	$word		f[^
#	@param	$pResult	ʊi[pz̎Q
#	@return	qbg
#
#------------------------------------------------------------------------------------------------------------
sub search
{
	my $this = shift;
	my ($index, $word, $pResult) = @_;
	my ($i, @elem, $num);
	
	$num = 0;
	for($i = 0 ; $i < $this->{'SIZE'} ; $i++) {
		@elem = split(/<>/, $this->{'LOGS'}->[$i]);
		if ($elem[$index] eq $word) {
			push @$pResult, $this->{'LOGS'}->[$i];
			$num++;
		}
	}
	return $num;
}
#============================================================================================================
#	Module END
#============================================================================================================
1;

==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/module/imrahil.pl <==
#============================================================================================================
#
#	OǗW[
#	imrahil.pl
#	-------------------------------------------------------------------------------------
#	2005.04.02 start
#
#============================================================================================================
package	IMRAHIL;
use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#	Modẽrbgɂ
#	--------------------------------------
#	0:ǎp
#	1:I[vƓɓeǂݍ
#	2:őTCY𒴂Oۑ
#	3`:gp
#------------------------------------------------------------------------------------------------------------

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($File, $Limit, $Mode) = @_;
	my ($obj, @LOGS);
	local *HANDLE;
	
	$obj = {
		'LOGS'		=> \@LOGS,
		'PATH'		=> $File,
		'SIZE'		=> 0,
		'HANDLE'	=> *HANDLE,
		'LIMIT'		=> $Limit,
		'STAT'		=> 0,
		'MODE'		=> $Mode
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	fXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DESTROY
{
	my $this = shift;
	
	# t@CI[vԂ̏ꍇ̓N[Y
	if ($this->{'STAT'}) {
		my $handle = $this->{'HANDLE'};
		if ($handle) {
#			eval
			{
				close $handle;
			};
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	OI[v
#	-------------------------------------------------------------------------------------
#	@param	$File	Ot@CpX(gq)
#	@param	$Limit	OőTCY
#	@param	$Mode	[h
#	@return	:0,s:-1
#
#------------------------------------------------------------------------------------------------------------
sub Open
{
	my $this = shift;
	my ($File, $Limit, $Mode) = @_;
	my $ret = -1;
	
	if (defined $File && defined $Limit && defined $Mode) {
		$this->{'PATH'} = $File;
		$this->{'LIMIT'} = $Limit;
		$this->{'MODE'} = $Mode;
	}
	else {
		$File = $this->{'PATH'};
		$Limit = int $this->{'LIMIT'};
		$Mode = int $this->{'MODE'};
	}
	
	if (defined  $this->{'HANDLE'}) {
		local *HANDLE;
		$this->{'HANDLE'} = *HANDLE;
	}
	$File .= '.cgi';
	
#	eval
	{
		if ($this->{'STAT'} == 0) {
			my $handle = $this->{'HANDLE'};
			open $handle, "+>> $File";
			flock $handle, 2 if ($Mode & 1);
			binmode $handle;
			
			$this->{'STAT'} = 1;
			$ret = 0;
			if ($Mode & 2) {
				$ret = $this->Read();
			}
		}
	};
	return $ret;
}

#------------------------------------------------------------------------------------------------------------
#
#	ON[Y
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Close
{
	my $this = shift;
	
	if ($this->{'STAT'} == 1) {
#		eval
		{
			my $handle = $this->{'HANDLE'};
			close $handle;
			$this->{'STAT'} = 0;
		};
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	ǂݍ
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	:0,s:-1
#
#------------------------------------------------------------------------------------------------------------
sub Read
{
	my $this = shift;
	my $ret = -1;
	
	if ($this->{'STAT'} == 1) {
#		eval
		{
			my $handle = $this->{'HANDLE'};
			my $count = 0;
			undef @{$this->{'LOGS'}};
			seek $handle, 0, 0;
			while (<$handle>) {
				chomp $_;
				push @{$this->{'LOGS'}}, $_;
				$count++;
			}
			$this->{'SIZE'} = $count;
			$ret = 0;
		};
	}
	return $ret;
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Write
{
	my $this = shift;
	
	# t@CI[vԂȂ珑݂s
	if ($this->{'STAT'}) {
		if (! ($this->{'MODE'} & 1)) {
			my $handle = $this->{'HANDLE'};
#			eval
			{
				truncate $handle, 0;
				seek $handle, 0, 0;
				for (my $i = 0 ; $i < $this->{'SIZE'} ; $i++) {
					print $handle $this->{'LOGS'}->[$i] . "\n";
				}
				close $handle;
			};
			$this->{'STAT'} = 0;
		}
		else {
			$this->Close();
		}
	}
}

#------------------------------------------------------------------------------------------------------------
#
#	f[^擾
#	-------------------------------------------------------------------------------------
#	@param	$line	擾f[^s
#	@return	擾f[^
#
#------------------------------------------------------------------------------------------------------------
sub Get
{
	my $this = shift;
	my ($line) = @_;
	
	if ($line >= 0 && $line < $this->{'SIZE'}) {
		return $this->{'LOGS'}->[$line];
	}
	return undef;
}

#------------------------------------------------------------------------------------------------------------
#
#	f[^ǉ
#	-------------------------------------------------------------------------------------
#	@param	$pData	ǉf[^
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Put
{
	my $this = shift;
	my (@datas) = @_;
	my ($logData, $tm);
	
	if ($this->{'SIZE'} + 1 > $this->{'LIMIT'}) {
		my $old = shift @{$this->{'LOGS'}};
		if ($this->{'MODE'} & 4) {
			my $logName = $this->{'PATH'} . '_old.cgi';
#			eval
			{
				open OLDLOG, ">> $logName";
				flock OLDLOG, 2;
				binmode OLDLOG;
				print OLDLOG "$old\n";
				close OLDLOG;
			};
		}
		$this->{'SIZE'}--;
	}
	$tm = time;
	$logData = join('<>', $tm, @datas);
	
	push @{$this->{'LOGS'}}, $logData;
	$this->{'SIZE'}++;
}

#------------------------------------------------------------------------------------------------------------
#
#	TCY擾
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	TCY
#
#------------------------------------------------------------------------------------------------------------
sub Size
{
	my $this = shift;
	return $this->{'SIZE'};
}

#------------------------------------------------------------------------------------------------------------
#
#	Oޔ
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub MoveToOld
{
	my $this = shift;
	my ($i);
	
#	eval
	{
		open OLDLOG, ">> " . $this->{'PATH'} . '_old.cgi';
		flock OLDLOG, 2;
		binmode OLDLOG;
		for($i = 0 ; $i < $this->{'SIZE'} ; $i++) {
			print OLDLOG $this->{'LOGS'}->[$i] . "\n";
		}
		close OLDLOG;
	};
}

#------------------------------------------------------------------------------------------------------------
#
#	ONA
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub Clear
{
	my $this = shift;
	
	undef @{$this->{'LOGS'}};
	$this->{'SIZE'} = 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	
#	-------------------------------------------------------------------------------------
#	@param	$index		vf̃CfNX
#	@param	$word		f[^
#	@param	$pResult	ʊi[pz̎Q
#	@return	qbg
#
#------------------------------------------------------------------------------------------------------------
sub search
{
	my $this = shift;
	my ($index, $word, $pResult) = @_;
	my ($i, @elem, $num);
	
	$num = 0;
	for($i = 0 ; $i < $this->{'SIZE'} ; $i++) {
		@elem = split(/<>/, $this->{'LOGS'}->[$i]);
		if ($elem[$index] eq $word) {
			push @$pResult, $this->{'LOGS'}->[$i];
			$num++;
		}
	}
	return $num;
}
#============================================================================================================
#	Module END
#============================================================================================================
1;
